[−]Enum eq_vesting::Call

pub enum Call<T: Trait> {
    vest(),
    vest_other(<T::Lookup as StaticLookup>::Source),
    vested_transfer(<T::Lookup as StaticLookup>::Source, VestingInfo<<<T as Trait>::Currency as Currency<<T as Trait>::AccountId>>::Balance, T::BlockNumber>),
    force_vested_transfer(<T::Lookup as StaticLookup>::Source, <T::Lookup as StaticLookup>::Source, VestingInfo<<<T as Trait>::Currency as Currency<<T as Trait>::AccountId>>::Balance, T::BlockNumber>),
    // some variants omitted
}

Dispatchable calls.

Each variant of this enum maps to a dispatchable function from the associated module.

Variants

vest()

Unlock any vested funds of the sender account.

The dispatch origin for this call must be Signed and the sender must have funds still locked under this module.

Emits either VestingCompleted or VestingUpdated.

vest_other(<T::Lookup as StaticLookup>::Source)

Unlock any vested funds of a target account.

The dispatch origin for this call must be Signed.

Emits either VestingCompleted or VestingUpdated.

vested_transfer(<T::Lookup as StaticLookup>::Source, VestingInfo<<<T as Trait>::Currency as Currency<<T as Trait>::AccountId>>::Balance, T::BlockNumber>)

Create a vested transfer.

The dispatch origin for this call must be Signed.

Emits VestingCreated.

force_vested_transfer(<T::Lookup as StaticLookup>::Source, <T::Lookup as StaticLookup>::Source, VestingInfo<<<T as Trait>::Currency as Currency<<T as Trait>::AccountId>>::Balance, T::BlockNumber>)

Force a vested transfer.

The dispatch origin for this call must be Root.

Emits VestingCreated.